pub struct CodeMap { /* private fields */ }Expand description
The code map contains the original source and can map VM instructions to text ranges inside that source.
Implementations
Sourceimpl CodeMap
impl CodeMap
Sourcepub fn new(text: impl Into<String>) -> CodeMap
pub fn new(text: impl Into<String>) -> CodeMap
Create a new, empty CodeMap from a text and a set of ranges.
Sourcepub fn map_instruction(
&mut self,
instruction: usize,
span: Span,
) -> Result<(), RangeError>
pub fn map_instruction( &mut self, instruction: usize, span: Span, ) -> Result<(), RangeError>
Add new mapping starting at instruction which maps to span.
Sourcepub fn span_from_instruction(
&self,
ip: usize,
) -> Result<SpannedText<'_>, RangeError>
pub fn span_from_instruction( &self, ip: usize, ) -> Result<SpannedText<'_>, RangeError>
Retrieve the Span containing the given instruction pointer.